@@ -24,13 +24,13 @@
 #include <gtk/gtk.h>
 #include <dbus/dbus-glib.h>
 
-enum ss_diverts {
-  SS_ALL_DIVERTS, /* Set only -- sets all diverts */
-  SS_DIVERT_ALL, /* Unconditional */
-  SS_DIVERT_BUSY, /* Divert on Busy */
-  SS_DIVERT_NO_REPLY, /* Divert on no reply */
-  SS_DIVERT_NO_REACH, /* Divert on not reachable */
-  SS_DIVERT_NO_AVAIL /* Set only -- sets all of SS_DIVERT_BUSY, SS_DIVERT_NO_REPLY and SS_DIVERT_NO_REACH */
+enum callforwardings {
+  CALLFORWARDING_ALL, /* set only */
+  CALLFORWARDING_UNCONDITIONAL, 
+  CALLFORWARDING_BUSY,
+  CALLFORWARDING_NO_ANSWER,
+  CALLFORWARDING_NO_REACH,
+  CALLFORWARDING_NO_AVAIL /* sets all busy, no reply & no reach */
 };
 
 
